@@ -411,8 +411,6 @@ class UnitCalculator(object):
         :param list_of_quantities: a list of ``pint.Quantity`` objects.
         :returns: boolean indicating whether all units are equivalent
         """
-        if len(list_of_quantities) == 1:
-            return True
 
         def _is_equal(quantity1, quantity2):
             assert isinstance(quantity1, self._registry.Quantity)
@@ -422,7 +420,7 @@ class UnitCalculator(object):
             return math.isclose(base1[0], base2[0]) and base1[1] == base2[1]
 
         list_of_quantities = iter(list_of_quantities)
-        first = next(list_of_quantities)
+        first = next(list_of_quantities, True)
         return all(_is_equal(first, rest) for rest in list_of_quantities)
 
     def _is_dimensionless(self, quantity):
@@ -436,7 +434,6 @@ class UnitCalculator(object):
         :param expr: a Sympy expression
         :returns: the quantity (i.e. magnitude(expression) * unit) of the expression
         :raises KeyError: if variable not found in metadata
-        :raises UnitsCannotBeCalculatedError: if expression just cannot calculate
         :raises UnexpectedMathUnitsError: if math is not supported
         :raises BooleanUnitsError: if math returns booleans
         :raises InputArgumentsMustBeDimensionlessError: if input arguments should be dimensionless
@@ -477,9 +474,11 @@ class UnitCalculator(object):
         if expr.is_Symbol:
 
             # is this symbol is a placeholder for a number
+            assert isinstance(expr, model.Quantity) or isinstance(expr, model.Variable), \
+                'Unexpected symbol type: ' + str(expr)
             if isinstance(expr, model.Quantity):
                 return float(expr) * expr.units
-            elif isinstance(expr, model.Variable):
+            else:
                 if expr.initial_value and expr.initial_value != 0.0:
                     #  if this symbol has an initial value (that is not zero)
                     # substitute with the initial value for unit arithmetic
@@ -487,8 +486,6 @@ class UnitCalculator(object):
                 else:
                     # otherwise, keep the symbol
                     return self._registry.Quantity(expr, expr.units)
-            else:   # pragma: no cover
-                raise RuntimeError('Unexpected symbol type: ' + str(expr))
 
         elif expr == sympy.oo:
             return math.inf * dimensionless
@@ -809,19 +806,6 @@ class UnitError(Exception):
         self.message += ('. Context: ' + message).format(expression)
 
 
-class UnitsCannotBeCalculatedError(UnitError):
-    """Generic invalid units error.
-
-    This will be thrown if the expressions or symbols involved in a calculation cannot be calculated.
-
-    :param expression: input expression in which the error occurred
-    """
-
-    def __init__(self, expression):
-        self.expression = expression
-        self.message = 'The units of this expression cannot be calculated.'
-
-
 class UnexpectedMathUnitsError(UnitError):
     """Invalid units error thrown when math encountered in an expression is outside the subset of MathML expected.
 
